﻿using Dto;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Shared;

namespace API.Controllers
{
    [Route("api/[controller]")]
    [Authorize]
    [ApiController]
    public class InquiriesController(ILogger<InquiriesController> logger, IInquiryService<InquiryDTO> inquiryService)
        : ControllerBase, IInquiryService<InquiryDTO>
    {
        [HttpGet("inquiries/{page}/{number}")]
        [ProducesResponseType(typeof(InquiryDTO), 200)]
        [ProducesResponseType(typeof(string), 204)]
        public IActionResult GetInquiries(int page, int number)
        {
            var nbInquiry = inquiryService.GetInquiries(page, number).Count();
            if (nbInquiry == 0)
            {
                logger.LogError("[ERREUR] Aucune enquête trouvé.");
                return StatusCode(204);
            }

            logger.LogInformation("[INFORMATION] {nb} Enquête(s) trouvée(s)", nbInquiry);
            return Ok(inquiryService.GetInquiries(page, number));
        }

        [HttpGet("inquiry/id/{id}")]
        [ProducesResponseType(typeof(InquiryDTO), 200)]
        [ProducesResponseType(typeof(string), 404)]
        public IActionResult GetInquiryById(int id)
        {
            try
            {
                logger.LogInformation("[INFORMATION] Enquête avec l'id {id} a été trouvé.", id);
                return Ok(inquiryService.GetInquiryById(id));
            }
            catch (ArgumentException)
            {
                logger.LogError("[ERREUR] Aucune enquête trouvée avec l'id {id}.", id);
                return NotFound();
            }
        }

        [HttpGet("inquiry/title/{title}")]
        [ProducesResponseType(typeof(InquiryDTO), 200)]
        [ProducesResponseType(typeof(string), 404)]
        public IActionResult GetInquiryByTitle(string title)
        {
            try
            {
                logger.LogInformation("[INFORMATION] Enquête avec le titre {title} a été trouvé.", title);
                return Ok(inquiryService.GetInquiryByTitle(title));
            }
            catch (ArgumentException)
            {
                logger.LogError("[ERREUR] Aucune enquête trouvée avec le titre {title}.", title);
                return NotFound();
            }
        }
    }
}