﻿using Entities;
using Microsoft.AspNetCore.Identity.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore;
using Microsoft.AspNetCore.Identity;

namespace DbContextLib
{
    public class UserDbContext : IdentityDbContext<IdentityUser>
    {
        public DbSet<UserEntity> Users { get; set; }
        public DbSet<BlackListEntity> BlackList { get; set; }
        public DbSet<InquiryEntity> Inquiry { get; set; }
        public DbSet<InquiryTableEntity> InquiryTable { get; set; }
        public DbSet<LessonEntity> Lesson { get; set; }
        public DbSet<ContentLessonEntity> ContentLessons { get; set; }
        public DbSet<ParagraphEntity> Paragraph { get; set; }
        public DbSet<SolutionEntity> Solutions { get; set; }
        public DbSet<SuccessEntity> Success { get; set; }
        public DbSet<NotepadEntity> Notepad { get; set; }
        public UserDbContext(DbContextOptions<UserDbContext> options) : base(options) { }
        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            if (!optionsBuilder.IsConfigured)
            {
                optionsBuilder.UseNpgsql("Host=localhost;Database=SQLuedo;Username=admin;Password=motdepasse");
            }
            base.OnConfiguring(optionsBuilder);
        }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            modelBuilder.Entity<UserEntity>().ToTable("user");
            modelBuilder.Entity<ContentLessonEntity>().HasKey(c => c.LessonId);
            modelBuilder.Entity<ContentLessonEntity>().HasKey(c => c.LessonPartId);
            modelBuilder.Entity<SuccessEntity>().HasKey(s => s.UserId);
            modelBuilder.Entity<SuccessEntity>().HasKey(s => s.InquiryId);
            base.OnModelCreating(modelBuilder);
        }
    }
}
